@@ -7,6 +7,7 @@ import pybedtools
 import pybedtools.featurefuncs
 import pybedtools.helpers
 
+
 def test_midpoint():
     """
     regression test for #98
@@ -20,19 +21,22 @@ def test_midpoint():
     def nothing(f):
         return f
 
-    input_bed = pybedtools.BedTool(
-        a, from_string=True).saveas("test_input.bed")
+    input_bed = pybedtools.BedTool(a, from_string=True).saveas("test_input.bed")
 
-    for func in [pybedtools.featurefuncs.midpoint, pybedtools.featurefuncs.center, nothing]:
+    for func in [
+        pybedtools.featurefuncs.midpoint,
+        pybedtools.featurefuncs.center,
+        nothing,
+    ]:
         input_bed_mid = input_bed.each(func)
         assert len(input_bed_mid) == 4
 
+
 # pysam is now handling bgzip
 # def test_bgzip_missing():
-# 
+#
 #     old_path = pybedtools.settings._tabix_path
 #     pybedtools.helpers.set_bgzip_path('somenonexistantpath')
 #     a = pybedtools.example_bedtool('a.bed')
 #     assert_raises(ValueError, a.tabix)
 #     pybedtools.helpers.set_bgzip_path(old_path)
-
